@@ -102,7 +102,8 @@ QString unescapeXML(const QString &str)
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent)
 {
-    _http = new QHttp(this);
+    QNetworkProxyFactory::setUseSystemConfiguration(true);
+    _accessManager = new QNetworkAccessManager(this);
     _toWindow = 0;
 
     createMenu();
@@ -290,7 +291,7 @@ void MainWindow::createConnects()
     connect(actionAbout_qtranslate, SIGNAL(triggered()), this, SLOT(aboutQTranslate()));
     connect(actionDonate, SIGNAL(triggered()), this, SLOT(donate()));
 
-    connect(_http, SIGNAL(requestFinished(int,bool)), this, SLOT(translateRequestFinished(int,bool)));
+    connect(_accessManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(translateRequestFinished(QNetworkReply*)));
 }
 
 void MainWindow::retranslateUi()
@@ -419,19 +420,21 @@ void MainWindow::translateRightToLeft()
 
 void MainWindow::googleTranslate(QString text, QString langFrom, QString langTo)
 {
-    QHttpRequestHeader header("GET", "/ajax/services/language/translate?v=1.0&q="+QUrl::toPercentEncoding(text)+"&langpair="+langFrom+"%7C"+langTo);
-    header.setValue("Host", "ajax.googleapis.com");
-    _http->setHost("ajax.googleapis.com");
-    header.setValue("User-Agent", "qTranslateForMaemo");
-    header.setValue("Accept-Charset", "utf-8;q=0.7,*;q=0.7");
-    header.setValue("Referer", "qTranslateForMaemo");
+
+    QNetworkRequest request;
+    request.setUrl( QUrl("http://ajax.googleapis.com/ajax/services/language/translate?v=1.0&q="+text+"&langpair="+langFrom+"|"+langTo));
+    request.setRawHeader("Host", "ajax.googleapis.com");
+    request.setRawHeader("User-Agent", "qTranslateForMaemo");
+    request.setRawHeader("Accept-Charset", "utf-8;q=0.7,*;q=0.7");
+    request.setRawHeader("Referer", "qTranslateForMaemo");
+    _accessManager->get(request);
 
     /*QByteArray params("v=1.0");
     params.append("&q="+QUrl::toPercentEncoding(text));
     params.append("&langpair="+langFrom+"%7C"+langTo);
     qDebug(params);*/
-    _translation = new QBuffer(this);
-    _http->request(header, QByteArray(), _translation);
+    //_translation = new QBuffer(this);
+    //_http->request(header, QByteArray(), _translation);
     //QMessageBox::information(this, tr("Tiddlers on Rails"),tr("Get a free wiki at <a href=\"http://aufundapp.de/tor\">Tiddler on Rails</a>. Access it everywhere."));
 }
 
@@ -512,10 +515,10 @@ void MainWindow::resizeEvent(QResizeEvent* event) {
         buttonRight_to_left->setIcon(icon2);
     } else {
         QIcon icon;
-        icon.addFile(QString::fromUtf8(":/images/images/arrowleft.png"), QSize(), QIcon::Normal, QIcon::Off);
+        icon.addFile(QString::fromUtf8(":/images/images/arrowright.png"), QSize(), QIcon::Normal, QIcon::Off);
         buttonLeft_to_right->setIcon(icon);
         QIcon icon2;
-        icon2.addFile(QString::fromUtf8(":/images/images/arrowright.png"), QSize(), QIcon::Normal, QIcon::Off);
+        icon2.addFile(QString::fromUtf8(":/images/images/arrowleft.png"), QSize(), QIcon::Normal, QIcon::Off);
         buttonRight_to_left->setIcon(icon2);
     }
 }
@@ -583,15 +586,15 @@ void MainWindow::createLangCodes()
     }
 }
 
-void MainWindow::translateRequestFinished(int requestId, bool error)
+void MainWindow::translateRequestFinished(QNetworkReply * reply)
  {
-    if (error) {
+    if (reply->error() != QNetworkReply::NoError) {
         QMessageBox::information(this, tr("HTTP"),
                                   tr("Translation failed: %1.")
-                                  .arg(_http->errorString()));
+                                  .arg(reply->errorString()));
     } else {
         bool ok = false;
-        QString jsonTranslation = unescapeJson(_translation->data(), &ok).trimmed();
+        QString jsonTranslation = unescapeJson(reply->readAll(), &ok).trimmed();
         qDebug() << jsonTranslation;
         QString translation = QString("");
         QRegExp regexp = QRegExp("\"translatedText\":\"(.*)\"");
@@ -614,5 +617,6 @@ void MainWindow::translateRequestFinished(int requestId, bool error)
         else
             texteditRight->setText(translation);
     }
+    reply->deleteLater();
 }
 
